clear
set scheme s1mono

// DEFINE WORKING DIRECTORY HERE
//cd "C:\Users\" // for pc
//cd "~/Dropbox/" // for mac

use anonymized_study1_luciddata.dta, replace

* rename lucid demographics as such
foreach var of varlist age-political_party {
 rename `var' lucid_`var'
}

* Ideology
rename qid1098 pol_ideo7
label var pol_ideo7 "Political ideology"

foreach var of varlist pol_ideo7 {
	local templabel : var label `var'
	rename `var' temp
	gen `var' = .
	replace `var'=-3 if temp=="Extremely Conservative"
	replace `var'=-2 if temp=="Conservative" 
	replace `var'=-1 if temp=="Slightly Conservative" 
	replace `var'=0 if temp=="Moderate, Middle of Road"
	replace `var'=1 if temp=="Slightly Liberal" 
	replace `var'=2 if temp=="Liberal" 
	replace `var'=3 if temp=="Extremely Liberal" 
	label var `var' "`templabel'"
	tab temp pol_ideo7, missing
	drop temp
}
summ pol_ideo7

label var presentbias "Present bias (Endorse being impulsive)"

* Agree measures
qui foreach var of varlist liberty_1 liberty_2 liberty_3 liberty_4 liberty_5 presentbias {
	local templabel : var label `var'
	rename `var' temp
	gen `var' = .
	replace `var'=0 if temp=="Strongly disagree"
	replace `var'=.25 if temp=="Somewhat disagree"
	replace `var'=.5 if temp=="Neither agree nor disagree"
	replace `var'=.75 if temp=="Somewhat agree"
	replace `var'=1 if temp=="Strongly agree"
	label var `var' "`templabel'"
	drop temp
}

alpha liberty_1-liberty_5
gen liberty_scale = (liberty_1+ liberty_2+liberty_3+abs(liberty_4-1)+liberty_5)/5
label var liberty_scale "Liberty endorsement (Scale 0-1)"

rename risktaking_1 temp
gen risktaking=real(temp)
drop temp
label var risktaking "Self described risk taking behavior (0-10)"

gen prior_flushot=real(fluvaccine)
drop fluvaccine
label var prior_flushot "How many times in last 5 years got flu shot (0-5)"

gen anypreexisting=0
replace anypreexisting=1 if preexisting ~="" & preexisting ~="None of the above"
label var anypreexisting "Have any pre existing COVID health risk (1=yes)"
drop preexisting

* Vaccine Confidence
label var q1227_1 "Vaccines are necessary to protect the health of people close to my age"
label var q1227_2 "Vaccines do a good job in preventing the diseases that they are intended to prevent"
label var q1227_3 "Vaccines are safe"
label var q1227_4 "If I do not vaccinate myself, I may get a disease and cause other people close to my age to get the disease"
label var q1227_5 "People receive too many vaccines"
label var q1227_6 "If I vaccinate myself, I may have serious side effects"
label var q1227_7 "In general, medical professionals in charge of vaccinations have my best interests at heart"
label var q1227_8 "I have a good relationship with my healthcare provider"
forvalues ctr=1(1)8 {
	rename q1227_`ctr' vacconf_`ctr'
	}

* Agree measures
qui foreach var of varlist vacconf_*  {
	local templabel : var label `var'
	rename `var' temp
	gen `var' = .
	replace `var'=0 if temp=="Strongly disagree"
	replace `var'=.25 if temp=="Somewhat disagree"
	replace `var'=.5 if temp=="Neither agree nor disagree"
	replace `var'=.75 if temp=="Somewhat agree"
	replace `var'=1 if temp=="Strongly agree"
	label var `var' "`templabel'"
	drop temp
}

alpha vacconf_*
gen vacconf_scale = (vacconf_1 + vacconf_2 + vacconf_3 + vacconf_4 + vacconf_7 + vacconf_8 + abs(vacconf_5-1) +abs(vacconf_6-1))/8
label var vacconf_scale "Vaccine Confidence Scale (Careful, pre or post!) (0-1)"

* Treatment

rename vaccinetreatment temp
gen vaccinetreatment=real(temp)
drop temp
label var vaccinetreatment "Assigned treatment message"

label define treatlabel 0 "Bird feeding/Placebo" 1 "Baseline/Control" 2 "Personal Freedom" 3 "Economic Freedom" 4 "Self-interest" 5 "Community interest" 6 "Community economic benefit" 7 "Guilt" 8 "Embarrassment/Shame" 9 "Anger" 10 "Trust in Science" 11 "Not Bravery"
label values  vaccinetreatment treatlabel

* Outcome measures

* Likely measures
foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccine_advisefriend {
	local templabel : var label `var'
	rename `var' temp
	gen `var' = .
	replace `var'=0 if temp=="Extremely unlikely"
	replace `var'=.25 if temp=="Somewhat unlikely"
	replace `var'=.5 if temp=="Neither likely nor unlikely"
	replace `var'=.75 if temp=="Somewhat likely"
	replace `var'=1 if temp=="Extremely likely"
	label var `var' "`templabel'"
	drop temp
	}
replace vaccinelikely_year=1 if vaccinelikely_3month==1
label var vaccinelikely_3month "Likelihood get vaccine first 3 months"
label var vaccinelikely_year "Likelihood get vaccine first year"
gen vaccinelikely_combined=vaccinelikely_year
replace vaccinelikely_combined=1.25 if vaccinelikely_3month==1
replace vaccinelikely_combined=vaccinelikely_combined/1.25
summ vaccinelikely_combined
label var vaccine_advisefriend  "Likelihood advise friend get vaccine"

foreach var of varlist vaccine_comfort {
	local templabel : var label `var'
	rename `var' temp
	gen `var' = .
	replace `var'=1 if temp=="Very uncomfortable"
	replace `var'=.75 if temp=="Somewhat uncomfortable"
	replace `var'=.5 if temp=="Neither comfortable nor uncomfortable"
	replace `var'=.25 if temp=="Somewhat comfortable"
	replace `var'=0 if temp=="Very comfortable"
	label var `var' "`templabel'"
	drop temp
	}
rename vaccine_comfort vaccine_discomfortunvac
label var vaccine_discomfortunvac "Discomfort with having unvaccinated friend visit elderly person"

* Judging others
qui foreach var of varlist judgingothers_1 judgingothers_2 judgingothers_3 judgingothers_4  {
	local templabel : var label `var'
	rename `var' temp
	gen `var' = .
	replace `var'=0 if temp=="Not at all"
	replace `var'=.25 if temp=="Slightly"
	replace `var'=.50 if temp=="Somewhat"
	replace `var'=.75 if temp=="Mostly"
	replace `var'=1 if temp=="Very"
	label var `var' "`templabel'"
	drop temp
}
alpha judgingothers_1-judgingothers_4

rename judgingothers_1 nonvac_trustworthy
rename judgingothers_2 nonvac_selfish
rename judgingothers_3 nonvac_likeable
rename judgingothers_4 nonvac_competent

label var nonvac_trustworthy "Non-VaccinatorTrustworthy"
label var nonvac_selfish "Non-VaccinatorSelfish"
label var nonvac_likeable "Non-VaccinatorLikeable"
label var nonvac_competent "Non-VaccinatorCompetent"

gen judging_nonvacscale = (abs(nonvac_trustworthy-1) + nonvac_selfish + abs(nonvac_likeable-1) + abs(nonvac_competent-1))/4
alpha nonvac_*

* New social distancing measures
foreach var of varlist sdoutcomes1_1-sdoutcomes1_11 sdoutcomes2_1-sdoutcomes2_9 attend_1-attend_4 alertcovid_1 alertcovid_2 persuadeothers  reportbusiness mask_1-mask_6 {
	local templabel : var label `var'
	rename `var' temp
	gen `var' = .
	replace `var'=0 if temp=="Extremely unlikely"
	replace `var'=.25 if temp=="Somewhat unlikely"
	replace `var'=.5 if temp=="Neither likely nor unlikely"
	replace `var'=.75 if temp=="Somewhat likely"
	replace `var'=1 if temp=="Extremely likely"
	label var `var' "`templabel'"
	drop temp
	}

label var sdoutcomes1_1 "Likelihood: Go to Grocery store"
label var sdoutcomes1_2 "Likelihood: Go to Coffee shop"
label var sdoutcomes1_3 "Likelihood: Cook at home"
label var sdoutcomes1_4 "Likelihood: Order takeout"
label var sdoutcomes1_5 "Likelihood: Go out to eat, OUTSIDE"
label var sdoutcomes1_6 "Likelihood: Go out to eat, INSIDE"
label var sdoutcomes1_7 "Likelihood: Attend Religious Service"
label var sdoutcomes1_8 "Likelihood: Go to library"
label var sdoutcomes1_9 "Likelihood: Go to Park"
label var sdoutcomes1_10 "Likelihood: Have elective medical procedure"
label var sdoutcomes1_11 "Likelihood: Visit family member's house"

rename sdoutcomes1_1 ly_grocery
rename sdoutcomes1_2 ly_coffeeshop 
rename sdoutcomes1_3 ly_cookathome
rename sdoutcomes1_4 ly_ordertakeout
rename sdoutcomes1_5 ly_outsideouttoeat
rename sdoutcomes1_6 ly_insideouttoeat
rename sdoutcomes1_7 ly_church
rename sdoutcomes1_8 ly_library
rename sdoutcomes1_9 ly_park
rename sdoutcomes1_10 ly_electivemed
rename sdoutcomes1_11 ly_familyhouse

label var sdoutcomes2_1 "Likelihood: Stream movie"
label var sdoutcomes2_2 "Likelihood: Attend rally/protest"
label var sdoutcomes2_3 "Likelihood: Work outside house"
label var sdoutcomes2_4 "Likelihood: Use public transport"
label var sdoutcomes2_5 "Likelihood: Go to store that bans masks"
label var sdoutcomes2_6 "Likelihood: Take airplane for work"
label var sdoutcomes2_7 "Likelihood: Take airplane for fun"
label var sdoutcomes2_8 "Likelihood: Go to store that requires masks"
label var sdoutcomes2_9 "Likelihood: Self quarantine if exposed"

rename sdoutcomes2_1 ly_streammovie
rename sdoutcomes2_2 ly_rallyprotest
rename sdoutcomes2_3 ly_workoutsidehome
rename sdoutcomes2_4 ly_publictransport
rename sdoutcomes2_5 ly_storebanmasks
rename sdoutcomes2_6 ly_airplanework
rename sdoutcomes2_7 ly_airplanefun
rename sdoutcomes2_8 ly_storereqmasks
rename sdoutcomes2_9 ly_selfquarantine

label var attend_1 "Likelihood: Attend 5-10 Inside gathering"
label var attend_2 "Likelihood: Attend 5-10 Outside gathering"
label var attend_3 "Likelihood: Attend 25+ Inside gathering"
label var attend_4 "Likelihood: Attend 25+ Outside gathering"

rename attend_1 ly_attend_small_inside
rename attend_2 ly_attend_small_outside
rename attend_3 ly_attend_big_inside
rename attend_4 ly_attend_big_outside

label var alertcovid_1 "Likelihood: Alert authorities if sick"
label var alertcovid_2 "Likelihood: Cooperate with contact tracing"

label var persuadeothers "How likely persuade friend/relative if not social distancing? (Scale 0-1)"
label var reportbusiness "How likely report business violating rules? (Scale 0-1)"

label var mask_1 "Mask if: Work outside home"
label var mask_2 "Mask if: Take public transport"
label var mask_3 "Mask if: Go for walk"
label var mask_4 "Mask if: Go shopping"
label var mask_5 "Mask if: Go to friend's house"
label var mask_6 "Mask if: Go to park"

rename mask_1 mask_work
rename mask_2 mask_publictransport
rename mask_3 mask_walk
rename mask_4 mask_shop
rename mask_5 mask_friendshouse
rename mask_6 mask_park

foreach var of varlist ly_* persuadeothers reportbusiness mask_* {
	di "******"
	di "`var'"
	tab `var'
	}

* Political interst
qui foreach var of varlist polinterest {
	local templabel : var label `var'
	rename `var' temp
	gen `var' = .
	replace `var'=0 if temp=="Never" 
	replace `var'=1 if temp=="Some of the time" 
	replace `var'=2 if temp=="About half the time" 
	replace `var'=3 if temp=="Most of the time"
	replace `var'=4 if temp=="Always" 
	label var `var' "`templabel'"
	drop temp
}
summ polinterest

*Religiosity
qui foreach var of varlist religiosity {
	local templabel : var label `var'
	rename `var' temp
	gen `var' = .
	replace `var'=0 if temp=="Never" 
	replace `var'=1 if temp=="Seldom" 
	replace `var'=2 if temp=="A few times a year" 
	replace `var'=3 if temp=="Once or twice a month"
	replace `var'=4 if temp=="Once a week" 
	replace `var'=5 if temp=="More than once a week" 
	label var `var' "`templabel'"
	drop temp
}
summ religiosity

* vote2016
qui foreach var of varlist vote2016 {
	local templabel : var label `var'
	rename `var' temp
	gen `var' = .
	replace `var'=0 if temp=="Donald Trump, the Republican"
	replace `var'=1 if temp=="Hillary Clinton, the Democrat"
	replace `var'=2 if temp=="I did not vote" 
	replace `var'=3 if temp=="Other"
	label var `var' "`templabel'"
	drop temp
}
summ vote2016

* Change to #
qui foreach var of varlist lucid_age *time* *timing* durationinseconds lucid_gender lucid_hhi lucid_ethnicity lucid_hispanic lucid_education lucid_region lucid_political_party progress {
	destring `var' , replace force
	}

* You had to get to 31 on progress to get through the vaccine stuff
drop if progress<31

///let's get some working and labeled covariates 
label var lucid_age "Age in years"

*gender
gen lucid_female = (lucid_gender==2)
label var lucid_female "Female (1=yes)"
drop lucid_gender

replace lucid_hhi=25 if lucid_hhi==. | lucid_hhi==-3105
label define inclabel 1 "Less than $14,999" 2 "$15,000 to $19,999" 3 "$20,000 to $24,999" 4 "$25,000 to $29,999" 5 " $30,000 to $34,999" 6 " $35,000 to $39,999" 7 "$40,000 to $44,999" 8 "$45,000 to $49,999" 9 " $50,000 to $54,999" 10 " $55,000 to $59,999" 11 "$60,000 to $64,999" 12 " $65,000 to $69,999" 13 "$70,000 to $74,999" 14 "$75,000 to $79,999" 15 "$80,000 to $84,999" 16 "$85,000 to $89,999" 17 "$90,000 to $94,999" 18 "$95,000 to $99,999" 19 "$100,000 to $124,999" 20 "$125,000 to $149,999" 21 "$150,000 to $174,999" 22 "$175,000 to $199,999" 23 " $200,000 to $249,999" 24 "$250,000 and above" 25 "Missing"
label values lucid_hhi inclabel
label var lucid_hhi "Lucid Household Income (1-24, 25=missing)"
gen lucid_incmissing=(lucid_hhi==25)
label var lucid_incmissing "Lucid Household Income missing"

*education
replace lucid_education = 4 if lucid_education==-3105
label def ed 1	"Some high school or less"2	"High school graduate"3	"Other post high school vocational training" 4	"Completed some college, but no degree (and missing)" 5	"Associate's degree"6	"Bachelor's degree"7	"Master's or professional degree"8	"Doctorate degree"
label val lucid_education ed
label var lucid_education "Lucid education scale (1-8)"

*party
gen lucid_party7 = 1 if lucid_political_party == 1
replace lucid_party7 = 2 if lucid_political_party == 2
replace lucid_party7 = 3 if lucid_political_party == 3|lucid_political_party == 6
replace lucid_party7 = 4 if lucid_political_party ==4|lucid_political_party == 7
replace lucid_party7 = 5 if lucid_political_party == 5|lucid_political_party == 8
replace lucid_party7 =6 if lucid_political_party == 9
replace lucid_party7 = 7 if lucid_political_party == 10
label def pty 1 "Strong Democrat" 2 "Democrat" 3 "Democrat Lean" 4 "Independent" 5 "Republican Lean" 6 "Republican" 7 "Strong Republican"
label val lucid_party7 pty
label var lucid_party7 "Lucid 7-pt Partisansip (1 = SD, 7=SR)"
drop lucid_political_party

tab lucid_party7, gen(partisanship_)
drop partisanship_4
label var partisanship_1 "Strong Democrat"
label var partisanship_2 "Democrat"
label var partisanship_3 "Democrat Lean"
label var partisanship_5 "Republican Lean"
label var partisanship_6 "Republican"
label var partisanship_7 "Strong Republican"

gen posttreat_vacconf_scale=vacconf_scale if confidencepretreatment =="0"
label var posttreat_vacconf_scale "Post-treatment vaccine confidence scale (0-1)"

label var vaccinelikely_combined "Likelihood of getting vaccine in first 3 months/1 year (combined, 0-1)"
label var judging_nonvacscale "Judgment of those who choose not to get vaccine"

	* reverse code measures in Social distancing behavior scale
	foreach var of varlist ly_church ly_library ly_electivemed ly_familyhouse ly_rallyprotest ly_publictransport ly_airplanefun ly_workoutsidehome ly_attend* {
	 gen prc_`var' = abs(1-`var')
	local templabel : var label `var'
	label var prc_`var' "RC `templabel'"

	 }
	unab temp: prc_*

	egen outcome_sdscale_ct=rownonmiss(ly_selfquarantine alertcovid_1 `temp')
	
	* Perform mean imputation for scale items
	foreach var of varlist ly_selfquarantine alertcovid_1 `temp' {
		gen Z`var' = `var'
		qui summ `var'
		replace Z`var'=`r(mean)' if Z`var'==.
		}
	egen outcome_sdscale=rowtotal(Z*)
	replace outcome_sdscale=outcome_sdscale/14
	* And make outcome missing if more than 25% of scale items are missing
	replace outcome_sdscale=. if outcome_sdscale_ct<10
	label var outcome_sdscale "Social distancing scale (14 items, 0-1)"
	factor prc_* ly_selfquarantine alertcovid_1
	alpha prc_* ly_selfquarantine alertcovid_1
	
forvalues ctr=1(1)11 {
 gen treat_`ctr'=vaccinetreatment==`ctr'
 local templabel : label (vaccinetreatment) `ctr'
 label var treat_`ctr' "Treat = `templabel'"
 }
 
label var treat_1 "T = Baseline"
label var treat_2 "T = Pers. Freedom"
label var treat_3 "T = Econ. Freedom"
label var treat_4 "T = Self-interest"
label var treat_5 "T = Comm. interest"
label var treat_6 "T = Comm. Econ. Ben."
label var treat_7 "T = Guilt"
label var treat_8 "T = Embarrassment"
label var treat_9 "T = Anger"
label var treat_10 "T = Trust in Science"
label var treat_11 "T = Not Bravery"
 
rename treat_1 treat_baseline
rename treat_2 treat_personalfreedom
rename treat_3 treat_economicfreedom
rename treat_4 treat_selfinterest
rename treat_5 treat_communityinterest
rename treat_6 treat_communityeconomicbenefit
rename treat_7 treat_guilt
rename treat_8 treat_embarassmentshame
rename treat_9 treat_anger
rename treat_10 treat_trustinscience
rename treat_11 treat_notbravery

order treat_baseline treat_selfinterest treat_communityinterest treat_guilt treat_embarassmentshame treat_anger treat_notbravery treat_trustinscience treat_personalfreedom treat_economicfreedom treat_communityeconomicbenefit

local ctr=1
gen lincom=""
gen lincomest=.
gen lincompvalue=.
gen lincomdv=""
gen lincomctr=.

foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale {
	summ `var'
	local t1=strofreal(r(mean),"%9.2f")
	local t2=strofreal(r(sd),"%9.2f")
	twoway (histogram `var', fraction bin(10)), name(`var', replace) note("Mean = `t1'; SD=`t2'")
}

graph combine vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale , xsize(8.5) ysize(11) scale(.7) rows(3)
graph export Graphs\Figure_S1.pdf, replace

* Not included: vaccine_discomfortunvac posttreat_vacconf_scale outcome_sdscale
* Create graphs by individual treatment items
foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale  {
	*summ `var'
	*twoway (histogram `var', discrete fraction), name(`var', replace) note("Mean = `r(mean)'; SD=`r(sd)'")
	*graph export graphs\sumstat_`var'.pdf, replace

	regress `var' treat_* lucid_age lucid_female lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot, robust
	est store `var'
	local `var'_bsln = _b[treat_baseline]
	
	qui foreach var2 of varlist treat_notbravery treat_trustinscience treat_personalfreedom treat_economicfreedom treat_selfinterest treat_communityeconomicbenefit treat_communityinterest treat_guilt treat_embarassmentshame treat_anger {
		lincom `var2' - treat_baseline
		replace lincomdv= "`var'" in `ctr' 
		replace lincom = "`var2' - treat_baseline" in `ctr'
		replace lincomest = `r(estimate)' in `ctr'
		replace lincompvalue=`r(p)'  in `ctr'
		replace lincomctr=`ctr' in `ctr'
		local ctr=`ctr'+1
	}
	
	qui summ `var' if e(sample) & vaccinetreatment==0
	
	if "`var'"=="vaccinelikely_3month" {
		*outreg using Tables\Table01_Study1_MainAnalysis.out, se bracket rdec(3) 3aster addstat("Ctr. Grp. Mean of DV",`r(mean)',"SD",`r(sd)') adec(3) replace

	}
	else {
		*outreg using Tables\Table01_Study1_MainAnalysis.out, se bracket rdec(3) 3aster addstat("Ctr. Grp. Mean of DV",`r(mean)',"SD",`r(sd)') adec(3) append
	}
	
}

preserve
keep lincom*
//outsheet using tables\Table01_Lincoms_MainAnalysis.out, comma replace
restore

* This is the analysis discussed in the text right after the Panel A, where we talk about magnitudes for the binary outcome

	gen vacbinarycomb =(vaccinelikely_comb > .5) & vaccinelikely_combined ~=.
	regress vacbinarycomb treat_* lucid_age lucid_female lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot, robust
	summ vacbinarycomb if e(sample) & vaccinetreatment==0
	di _b[treat_embarassmentshame]/r(mean)
	di (_b[treat_embarassmentshame]-_b[treat_baseline])/(r(mean)+_b[treat_baseline])
	
	*This was for the 3 month analysis that was reported in the original version of the manuscript (CAN BE REMOVED PRIOR TO POSTING REPLICATION MATERIALS)
	gen vacbinary3mos=(vaccinelikely_3month ==1 | vaccinelikely_3month==.75) & vaccinelikely_3month ~=.
	regress vacbinary3mos treat_* lucid_age lucid_female lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot, robust
	summ vacbinary3mos if e(sample) & vaccinetreatment==0
	di _b[treat_embarassmentshame]/r(mean)
	di (_b[treat_embarassmentshame]-_b[treat_baseline])/(r(mean)+_b[treat_baseline])

* This is the analysis discussed in the text right after the Panel B, where we talk about magnitudes for the binary outcome

	gen advisebinary=vaccine_advisefriend>=.7 & vaccine_advisefriend~=.
	regress advisebinary treat_* lucid_age lucid_female lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot, robust
	summ advisebinary if e(sample) & vaccinetreatment==0
	di _b[treat_embarassmentshame]/r(mean)
	di (_b[treat_embarassmentshame]-_b[treat_baseline])/(r(mean)+_b[treat_baseline])

local sublbl = "All"

coefplot vaccinelikely_combined , keep(*:treat*) omitted levels(95) baselevels  xline(0) xline(`vaccinelikely_combined_bsln',lpattern(dash))  title("A: Intention to Vaccinate", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(off)  name(`sublbl'A, replace) 

coefplot vaccine_advisefriend , keep(*treat*) omitted levels(95) baselevels  xline(0) xline(`vaccine_advisefriend_bsln', lpattern(dash)) title("B: Advise Friend", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Advise friend") size(vsmall) off)  name(`sublbl'B, replace) 

coefplot judging_nonvacscale , keep(*treat*) omitted levels(95) baselevels  xline(0) xline(`vaccine_advisefriend_bsln', lpattern(dash)) title("C: Judging Non-Vaccinator", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Judging Non-Vaccinator") size(vsmall) off)  name(`sublbl'C, replace) 

graph combine `sublbl'A `sublbl'B `sublbl'C, cols(3) iscale(*.8) title("") xsize(11) ysize(8.5) scale(.8)

graph export graphs\Figure_1.pdf, replace

* This is the subgroup analysis
gen tottimingvaccine = demo1timing_pagesubmit + mfttiming_pagesubmit + mft2timing_pagesubmit + preexistingtiming_pagesubmit + treatmenttiming_pagesubmit

forvalues ctr = 1(1)13 {
	
	preserve

	if `ctr'==1 {
		local subgroup = "Eliminate very fast/slow respondents"
		local covariates = "lucid_age lucid_female lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot"
		local sn = "01_speed"
		qui summ duration, detail
		drop if duration<r(p10) | duration>r(p90)
		}
	if `ctr'==2 {
		local subgroup "Young (Age<35)"
		local covariates = "lucid_female lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot"
		local sn = "02_young"
		drop if lucid_age>=35
		}
	if `ctr'==3 {
		local subgroup "Old (Age>=35)"
		local covariates = "lucid_age lucid_female lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot"
		local sn = "03_old"
		drop if lucid_age<35
		}
	if `ctr'==4 {
		local subgroup "Men"
		local covariates = "lucid_age lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot"
		local sn = "04_men"
		drop if lucid_female~=0
		}
	if `ctr'==5 {
		local subgroup "Women"
		local covariates = "lucid_age lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot"
		local sn = "05_women"
		drop if lucid_female~=1
		}
	if `ctr'==6 {
		local subgroup "Low risktaking"
		local covariates = "lucid_age lucid_female lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot"
		local sn = "06_lowrisktaker"
		drop if risktaking>6 | risktaking==.
		}
 	if `ctr'==7 {
		local subgroup "High risktaking"
		local covariates = "lucid_age lucid_female lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot"
		local sn = "07_highrisktaker"
		drop if risktaking<=6 | risktaking==.
		}
	if `ctr'==8 {
		local subgroup "Democrats"
		local covariates = "lucid_age lucid_female lucid_hhi lucid_incmissing i.lucid_education anypreexisting i.prior_flushot"
		local sn = "08_dems"
		keep if lucid_party7==1 | lucid_party7==2 | lucid_party7==3
		}
 	if `ctr'==9 {
		local subgroup "Republicans"
		local covariates = "lucid_age lucid_female lucid_hhi lucid_incmissing i.lucid_education anypreexisting i.prior_flushot"
		local sn = "09_reps"
		keep if lucid_party7==5 | lucid_party7==6 | lucid_party7==7
		}
 	if `ctr'==10 {
		local subgroup "Low Liberty Scale"
		local covariates = "lucid_age lucid_female lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot"
		local sn = "10_lowliberty"
		keep if liberty_scale<.65
		}		
 	if `ctr'==11 {
		local subgroup "High Liberty Scale"
		local covariates = "lucid_age lucid_female lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot"
		local sn = "11_highliberty"
		keep if liberty_scale>=.65
		}		
 	if `ctr'==12 {
		local subgroup "Low Present Bias"
		local covariates = "lucid_age lucid_female lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot"
		local sn = "12_lowpresentbias"
		keep if presentbias<.4
		}		
 	if `ctr'==13 {
		local subgroup "High Present Bias"
		local covariates = "lucid_age lucid_female lucid_hhi lucid_incmissing i.lucid_education partisanship_* anypreexisting i.prior_flushot"
		local sn = "13_highresentbias"
		keep if presentbias>.4
		}	
	
	foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend vaccine_discomfortunvac judging_nonvacscale posttreat_vacconf_scale {
		regress `var' treat_* `covariates', robust
		est store `var'
		
		qui summ `var' if e(sample) & vaccinetreatment==0
	
		if "`var'"=="vaccinelikely_3month" {
		//	outreg2 using Tables\Table01_Study1_`sn'.out, se bracket rdec(3) addstat("Ctr. Grp. Mean of DV",`r(mean)',"SD",`r(sd)') adec(3) addnote("`subgroup'") replace

		}
		else {
		//	outreg2 using Tables\Table01_Study1_`sn'.out, se bracket rdec(3) addstat("Ctr. Grp. Mean of DV",`r(mean)',"SD",`r(sd)') adec(3) append
		}
		
	}

	coefplot  vaccinelikely_3month vaccinelikely_year vaccinelikely_combined , keep(*:treat*) omitted levels(95) baselevels  xline(0) title("A: Intention to Vaccinate", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Vaccine 3 Mos." 4 "Vaccine Year" 6 "Vaccine Combo") size(vsmall) on) note("`subgroup'.")  name(A, replace) 
	coefplot    vaccine_advisefriend judging_nonvacscale, keep(*treat*) omitted levels(95) baselevels  xline(0) title("B: Other-Regarding Outcomes", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Advise friend" 4 "Judging Non-Vaccinator") size(vsmall) on) note("`subgroup'.")  name(B, replace) 
	
	graph combine A B, cols(2) iscale(*.8) title("") xsize(11) ysize(8.5) scale(.8)
	graph export graphs\G_`sn'.pdf, replace

	restore
}
