clear
set scheme s1mono

// DEFINE WORKING DIRECTORY HERE
cd "C:\Users\" // for pc
//cd "~/Dropbox/" // for mac

use anonymizedYouGovSurveyData.dta

label var age "Age (5 categories)"
gen female=gender==2
label var female "Female"

gen income = faminc_new
replace income=17 if faminc_new==97
gen income_miss= faminc_new==97
label var income "Family income (1-17)"
label var income_miss "Income missing"

label var educ "Education (6 categories)"

gen pid7_nomiss=pid7
replace pid7_nomiss=4 if pid7==8
label var pid7_nomiss "PID 7 Categories"

gen race_black=race4==2
gen race_hispanic=race==3
gen race_other=race==4
label var race_black "Black"
label var race_hispanic "Hispanic"
label var race_other "Other Non-White"

gen notworking=dem_workoutside=="4" | dem_workoutside=="NA"
gen workathome=dem_workoutside=="2"
gen workoutsidechoice=(dem_workoutside=="1" | dem_workoutside=="3") & dem_choice=="1"
gen workoutsidehaveto=(dem_workoutside=="1" | dem_workoutside=="3") & dem_choice=="2"
label var notworking "Not working"
label var workathome "Working at home"
label var workoutsidechoice "Working outside home, by choice"
label var workoutsidehaveto "Working outside home, have to"

* any Covid-19 health risk?

gen anyhealthrisk=healthrisk_12==2
label var anyhealthrisk "Any COVID-19 health risk"

gen prior_flushot=fluvaccine-1
drop fluvaccine
label var prior_flushot "How many times in last 5 years got flu shot (0-5)"

gen pid_3_withlean=.
replace pid_3_withlean=0 if pid7_with_leaners==1
replace pid_3_withlean=1 if pid7_with_leaners==3
replace pid_3_withlean=2 if pid7_with_leaners==2
label define pid3lab 0 "Democrat" 1 "Independent" 2 "Republican"
label values pid_3_withlean pid3lab

* Make sure variables not stores as string
foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccine_advisefriend judgingothers_1 judgingothers_2 judgingothers_3 judgingothers_4 judgingothers_5 {
	capture confirm string var `var'
	if _rc==0 {
		di "`var' is string"
		rename `var' temp
		gen `var'=real(temp)
		drop temp
	}
}

* Vaccine Confidence
forvalues ctr=1(1)8 {

	capture confirm string var vaccine_confidence_`ctr'
	if _rc==0 {
		gen vacconf_`ctr'=real(vaccine_confidence_`ctr')-1
	}
	else {
		gen vacconf_`ctr'=vaccine_confidence_`ctr'-1
	}
	drop vaccine_confidence_`ctr'
	
}

label var vacconf_1 "Vaccines are necessary to protect the health of people close to my age"
label var vacconf_2 "Vaccines do a good job in preventing the diseases that they are intended to prevent"
label var vacconf_3 "Vaccines are safe"
label var vacconf_4 "If I do not vaccinate myself, I may get a disease and cause other people close to my age to get the disease"
label var vacconf_5 "People receive too many vaccines"
label var vacconf_6 "If I vaccinate myself, I may have serious side effects"
label var vacconf_7 "In general, medical professionals in charge of vaccinations have my best interests at heart"
label var vacconf_8 "I have a good relationship with my healthcare provider"

* Agree measures
qui foreach var of varlist vacconf_*  {
	replace `var'=(`var')/4
}

alpha vacconf_*
gen vacconf_scale = (vacconf_1 + vacconf_2 + vacconf_3 + vacconf_4 + vacconf_7 + vacconf_8 + abs(vacconf_5-1) +abs(vacconf_6-1))/8
label var vacconf_scale "Vaccine Confidence Scale (Pre) (0-1)"
summ vacconf_scale

* liberty scale measures
qui foreach var of varlist liberty1 liberty2 liberty3 liberty4 liberty5 {
	local templabel : var label `var'
	rename `var' temp
	gen `var' = .
	replace `var'=0 if temp=="1"
	replace `var'=.25 if temp=="2"
	replace `var'=.5 if temp=="3"
	replace `var'=.75 if temp=="4"
	replace `var'=1 if temp=="5"
	label var `var' "`templabel'"
	drop temp
}
gen liberty_scale = (liberty1+ liberty2+liberty3+abs(liberty4-1)+liberty5)/5
label var liberty_scale "Liberty endorsement (Scale 0-1)"

gen risktaking=real(risktaking_scl)
label var risktaking "Risk taking scale (0-10)"



/*
T1: Control/Birdfeeding
T2: Information Baseline Control 2
T3: Not Bravery 3
T4: Trust in Science 4
T5: Personal Freedom 5
T6: Community Interest 6
T7: Community Interest + Anticipated
Embarrassment
*/

label define treatlabel 1 "Bird feeding/Placebo" 2 "Baseline Info." 3 "Not Bravery" 4 "Trust in Science" 5 "Personal Freedom" 6 "Community interest" 7 "Community interest + Embarrassment"
label values   message_split treatlabel

gen treat_info = message_split==2
gen treat_notbravery = message_split==3
gen treat_science = message_split==4
gen treat_freedom = message_split==5
gen treat_comm = message_split==6
gen treat_commembarass = message_split==7

label var treat_info "T = Baseline Info." 
label var treat_notbravery "T = Not Bravery"
label var treat_science "T = Trust in Science"
label var treat_freedom "T = Personal Freedom"
label var treat_comm "T = Community interest" 
label var treat_commembarass "T = Embarrassment" 

order treat_info treat_comm treat_commembarass treat_notbravery treat_science treat_freedom

foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccine_advisefriend {
	replace `var' = (`var'-1)/4
	}
	
replace vaccinelikely_year=1 if vaccinelikely_3month==1
label var vaccinelikely_3month "Likelihood get vaccine first 3 months"
label var vaccinelikely_year "Likelihood get vaccine first year"
gen vaccinelikely_combined=vaccinelikely_year
replace vaccinelikely_combined=1.25 if vaccinelikely_3month==1
replace vaccinelikely_combined=vaccinelikely_combined/1.25
summ vaccinelikely_combined
label var vaccine_advisefriend  "Likelihood advise friend get vaccine"

foreach var of varlist judgingothers_1 judgingothers_2 judgingothers_3 judgingothers_4 judgingothers_5  {
	replace `var' = (`var'-1)/4
}

rename judgingothers_1 nonvac_trustworthy
rename judgingothers_2 nonvac_selfish
rename judgingothers_3 nonvac_likeable
rename judgingothers_4 nonvac_competent
rename judgingothers_5 nonvac_intell

label var nonvac_trustworthy "Non-VaccinatorTrustworthy"
label var nonvac_selfish "Non-VaccinatorSelfish"
label var nonvac_likeable "Non-VaccinatorLikeable"
label var nonvac_competent "Non-VaccinatorCompetent"
label var nonvac_intell "Non-VaccinatorIntelligent"

gen judging_nonvacscale = (abs(nonvac_trustworthy-1) + nonvac_selfish + abs(nonvac_likeable-1) + abs(nonvac_competent-1) + abs(nonvac_intell-1))/5
alpha nonvac_*
label var judging_nonvacscale "Judgment of non-vaccinators (5 item scale, 0-1)"

* attention check
gen attention_check_score=(attn_check=="3")+(money_steal=="2")
label var attention_check_score "Number of attention check items correct (0-2)"

* Distribtuion for outcomes
foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale {
	summ `var'
	local t1=strofreal(r(mean),"%9.2f")
	local t2=strofreal(r(sd),"%9.2f")
	twoway (histogram `var', fraction bin(10)), name(`var', replace) note("Mean = `t1'; SD=`t2'")
}

graph combine vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale , xsize(8.5) ysize(11) scale(.7) rows(3)
graph export Vaccines_rr_graphs\DistOfOutcomes.pdf, replace

* Core paper analysis.

local sublbl="All"
local subcondition=""

foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale  {
	regress `var' treat_* i.age female income income_miss i.educ i.pid7_nomiss race_black race_hispanic race_other workathome workoutsidechoice workoutsidehaveto prior_flushot vacconf_scale anyhealthrisk `subcondition', level(90) robust
	
	est store `var'
	local `var'_bsln = _b[treat_info]
	/*
	foreach test2 of varlist treat_notbravery treat_science treat_freedom treat_comm treat_commembarass {
		lincom `test2' - treat_info
		local te_`test2'=`r(estimate)'
		local tp_`test2'=`r(p)'
	}
		
	qui summ `var' if e(sample) & message_split==1
	if "`var'" == "vaccinelikely_3month" {
		outreg using Vaccines_rr_tables\TableX_`sublbl'.out, se bracket rdec(3) adec(3) 3aster addstat("Control Group Mean of DV",`r(mean)',"TNB v Info p",`tp_treat_notbravery',"TTS v Info p",`tp_treat_science',"TPF v Info p",`tp_treat_freedom',"TCI v Info p",`tp_treat_comm',"TCIE v Info p",`tp_treat_commembarass') replace
	}
	else {
		outreg using Vaccines_rr_tables\TableX_`sublbl'.out, se bracket rdec(3) adec(3) 3aster addstat("Control Group Mean of DV",`r(mean)',"TNB v Info p",`tp_treat_notbravery',"TTS v Info p",`tp_treat_science',"TPF v Info p",`tp_treat_freedom',"TCI v Info p",`tp_treat_comm',"TCIE v Info p",`tp_treat_commembarass') append
	}
	*/
}	

coefplot vaccinelikely_combined , keep(*treat*) omitted levels(90) baselevels  xline(0) xline(`vaccinelikely_combined_bsln',lpattern(dash)) title("A: Intention to Vaccinate", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Vaccine Combo") size(vsmall) off)  name(`sublbl'A, replace) 

coefplot vaccine_advisefriend , keep(*treat*) omitted levels(90) baselevels  xline(0) xline(`vaccine_advisefriend_bsln',lpattern(dash)) title("B: Advise Friend", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Advise Friend") size(vsmall) off)  name(`sublbl'B, replace) 

coefplot judging_nonvacscale, keep(*treat*) omitted levels(90) baselevels  xline(0) xline(`judging_nonvacscale_bsln',lpattern(dash)) title("C: Judging Non-Vaccinator", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Judging Non-Vaccinator") size(vsmall) off)  name(`sublbl'C, replace) 

graph combine `sublbl'A `sublbl'B `sublbl'C, cols(3) iscale(*.8) title("") xsize(11) ysize(8.5) scale(.8)
graph export Vaccines_rr_graphs\G_`sublbl'.pdf, replace
	if "`sublbl'" == "All" graph export Vaccines_rr_graphs\Figure_2.pdf, replace
	
* This is the analysis discussed in the text right after the Panel A, where we talk about magnitudes for the binary outcome
	
	gen vacbinarycomb=(vaccinelikely_combined > .5) & vaccinelikely_combined ~=.
	regress vacbinarycomb treat_* i.age female income income_miss i.educ i.pid7_nomiss race_black race_hispanic race_other workathome workoutsidechoice workoutsidehaveto prior_flushot vacconf_scale anyhealthrisk, robust level(90)
	summ vacbinarycomb if e(sample) & message_split==1
	di _b[treat_comm]/r(mean)
	di (_b[treat_comm]-_b[treat_info])/(r(mean)+_b[treat_info])
	lincom treat_comm-treat_info
	
	*Analysis from the first paper
	
	gen vacbinary3mos=(vaccinelikely_3month ==1 | vaccinelikely_3month==.75) & vaccinelikely_3month ~=.
	regress vacbinary3mos treat_* i.age female income income_miss i.educ i.pid7_nomiss race_black race_hispanic race_other workathome workoutsidechoice workoutsidehaveto prior_flushot vacconf_scale anyhealthrisk, robust 
	summ vacbinary3mos if e(sample) & message_split==1
	di _b[treat_comm]/r(mean)
	di (_b[treat_comm]-_b[treat_info])/(r(mean)+_b[treat_info])
	lincom treat_comm-treat_info

* This is the analysis discussed in the text right after the Panel B, where we talk about magnitudes for the binary outcome

	gen advisebinary=vaccine_advisefriend>=.7 & vaccine_advisefriend~=.
	regress advisebinary treat_* i.age female income income_miss i.educ i.pid7_nomiss race_black race_hispanic race_other workathome workoutsidechoice workoutsidehaveto prior_flushot vacconf_scale anyhealthrisk, robust level(90)
	summ advisebinary if e(sample) & message_split==1
	di _b[treat_commembarass]/r(mean)
	di (_b[treat_commembarass]-_b[treat_info])/(r(mean)+_b[treat_info])

* Pass attention check

local sublbl="Attentive"
local subcondition=`"if attn_check=="3""'

foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale  {
	regress `var' treat_* i.age female income income_miss i.educ i.pid7_nomiss race_black race_hispanic race_other workathome workoutsidechoice workoutsidehaveto prior_flushot vacconf_scale anyhealthrisk `subcondition', robust
	
	est store `var'
	
	foreach test2 of varlist treat_notbravery treat_science treat_freedom treat_comm treat_commembarass {
		lincom `test2' - treat_info
		local te_`test2'=`r(estimate)'
		local tp_`test2'=`r(p)'
	}

	qui summ `var' if e(sample) & message_split==1
	if "`var'" == "vaccinelikely_3month" {
	//	outreg2 using Vaccines_rr_tables\TableX_`sublbl'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)',"TNB v Info p",`tp_treat_notbravery',"TTS v Info p",`tp_treat_science',"TPF v Info p",`tp_treat_freedom',"TCI v Info p",`tp_treat_comm',"TCIE v Info p",`tp_treat_commembarass') replace
	}
	else {
	//	outreg2 using Vaccines_rr_tables\TableX_`sublbl'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)',"TNB v Info p",`tp_treat_notbravery',"TTS v Info p",`tp_treat_science',"TPF v Info p",`tp_treat_freedom',"TCI v Info p",`tp_treat_comm',"TCIE v Info p",`tp_treat_commembarass') append
	}
	
}	

coefplot  vaccinelikely_3month vaccinelikely_year vaccinelikely_combined , keep(*treat*) omitted levels(90) baselevels  xline(0) title("A: Intention to Vaccinate", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Vaccine 3 Mos." 4 "Vaccine Year" 6 "Vaccine Combo") size(vsmall) on) note("`sublbl'. Comparison to untreated control.")  name(`sublbl'A, replace) 
coefplot    vaccine_advisefriend judging_nonvacscale, keep(*treat*) omitted levels(90) baselevels  xline(0) title("B: Other-Regarding Outcomes", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Advise friend" 4 "Judging Non-Vaccinator") size(vsmall) on) note("`sublbl'. Comparison to untreated control.")  name(`sublbl'B, replace) 
graph combine `sublbl'A `sublbl'B, cols(2) iscale(*.8) title("") xsize(11) ysize(8.5) scale(.8)
graph export Vaccines_rr_graphs\G_`sublbl'.pdf, replace

* State fixed effects

local sublbl="StateFE"
local subcondition="i.inputstate"

foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale  {
	regress `var' treat_* i.age female income income_miss i.educ i.pid7_nomiss race_black race_hispanic race_other workathome workoutsidechoice workoutsidehaveto prior_flushot vacconf_scale anyhealthrisk `subcondition', robust
	
	est store `var'

	foreach test2 of varlist treat_notbravery treat_science treat_freedom treat_comm treat_commembarass {
		lincom `test2' - treat_info
		local te_`test2'=`r(estimate)'
		local tp_`test2'=`r(p)'
	}

	qui summ `var' if e(sample) & message_split==1
	if "`var'" == "vaccinelikely_3month" {
	//	outreg2 using Vaccines_rr_tables\TableX_`sublbl'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)',"TNB v Info p",`tp_treat_notbravery',"TTS v Info p",`tp_treat_science',"TPF v Info p",`tp_treat_freedom',"TCI v Info p",`tp_treat_comm',"TCIE v Info p",`tp_treat_commembarass') replace
	}
	else {
	//	outreg2 using Vaccines_rr_tables\TableX_`sublbl'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)',"TNB v Info p",`tp_treat_notbravery',"TTS v Info p",`tp_treat_science',"TPF v Info p",`tp_treat_freedom',"TCI v Info p",`tp_treat_comm',"TCIE v Info p",`tp_treat_commembarass') append
	}

}	

coefplot  vaccinelikely_3month vaccinelikely_year vaccinelikely_combined , keep(*treat*) omitted levels(90) baselevels  xline(0) title("A: Intention to Vaccinate", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Vaccine 3 Mos." 4 "Vaccine Year" 6 "Vaccine Combo") size(vsmall) on) note("`sublbl'. Comparison to untreated control.")  name(`sublbl'A, replace) 
coefplot    vaccine_advisefriend judging_nonvacscale, keep(*treat*) omitted levels(90) baselevels  xline(0) title("B: Other-Regarding Outcomes", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Advise friend" 4 "Judging Non-Vaccinator") size(vsmall) on) note("`sublbl'. Comparison to untreated control.")  name(`sublbl'B, replace) 
graph combine `sublbl'A `sublbl'B, cols(2) iscale(*.8) title("") xsize(11) ysize(8.5) scale(.8)
graph export Vaccines_rr_graphs\G_`sublbl'.pdf, replace

* Weighted

local sublbl="Weighted"
local subcondition=" [aweight=weight]"

foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale  {
	regress `var' treat_* i.age female income income_miss i.educ i.pid7_nomiss race_black race_hispanic race_other workathome workoutsidechoice workoutsidehaveto prior_flushot vacconf_scale anyhealthrisk `subcondition', robust
	
	est store `var'
	
	foreach test2 of varlist treat_notbravery treat_science treat_freedom treat_comm treat_commembarass {
		lincom `test2' - treat_info
		local te_`test2'=`r(estimate)'
		local tp_`test2'=`r(p)'
	}
	qui summ `var' if e(sample) & message_split==1
	if "`var'" == "vaccinelikely_3month" {
		outreg2 using Vaccines_rr_tables\TableX_`sublbl'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)',"TNB v Info p",`tp_treat_notbravery',"TTS v Info p",`tp_treat_science',"TPF v Info p",`tp_treat_freedom',"TCI v Info p",`tp_treat_comm',"TCIE v Info p",`tp_treat_commembarass') replace
	}
	else {
		outreg2 using Vaccines_rr_tables\TableX_`sublbl'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)',"TNB v Info p",`tp_treat_notbravery',"TTS v Info p",`tp_treat_science',"TPF v Info p",`tp_treat_freedom',"TCI v Info p",`tp_treat_comm',"TCIE v Info p",`tp_treat_commembarass') append
	}		
}	

coefplot  vaccinelikely_3month vaccinelikely_year vaccinelikely_combined , keep(*treat*) omitted levels(90) baselevels  xline(0) title("A: Intention to Vaccinate", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Vaccine 3 Mos." 4 "Vaccine Year" 6 "Vaccine Combo") size(vsmall) on) note("`sublbl'. Comparison to untreated control.")  name(`sublbl'A, replace) 
coefplot    vaccine_advisefriend judging_nonvacscale, keep(*treat*) omitted levels(90) baselevels  xline(0) title("B: Other-Regarding Outcomes", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Advise friend" 4 "Judging Non-Vaccinator") size(vsmall) on) note("`sublbl'. Comparison to untreated control.")  name(`sublbl'B, replace) 
graph combine `sublbl'A `sublbl'B, cols(2) iscale(*.8) title("") xsize(11) ysize(8.5) scale(.8)
graph export Vaccines_rr_graphs\G_`sublbl'.pdf, replace

* No covariates

local sublbl="NoCovariates"
local subcondition=""

foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale  {
	regress `var' treat_* `subcondition', robust
	
	est store `var'
	
	foreach test2 of varlist treat_notbravery treat_science treat_freedom treat_comm treat_commembarass {
		lincom `test2' - treat_info
		local te_`test2'=`r(estimate)'
		local tp_`test2'=`r(p)'
	}
	qui summ `var' if e(sample) & message_split==1
	if "`var'" == "vaccinelikely_3month" {
		outreg2 using Vaccines_rr_tables\TableX_`sublbl'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)',"TNB v Info p",`tp_treat_notbravery',"TTS v Info p",`tp_treat_science',"TPF v Info p",`tp_treat_freedom',"TCI v Info p",`tp_treat_comm',"TCIE v Info p",`tp_treat_commembarass') replace
	}
	else {
		outreg2 using Vaccines_rr_tables\TableX_`sublbl'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)',"TNB v Info p",`tp_treat_notbravery',"TTS v Info p",`tp_treat_science',"TPF v Info p",`tp_treat_freedom',"TCI v Info p",`tp_treat_comm',"TCIE v Info p",`tp_treat_commembarass') append
	}		
}	

coefplot  vaccinelikely_3month vaccinelikely_year vaccinelikely_combined , keep(*treat*) omitted levels(90) baselevels  xline(0) title("A: Intention to Vaccinate", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Vaccine 3 Mos." 4 "Vaccine Year" 6 "Vaccine Combo") size(vsmall) on) note("`sublbl'. Comparison to untreated control.")  name(`sublbl'A, replace) 
coefplot    vaccine_advisefriend judging_nonvacscale, keep(*treat*) omitted levels(90) baselevels  xline(0) title("B: Other-Regarding Outcomes", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Advise friend" 4 "Judging Non-Vaccinator") size(vsmall) on) note("`sublbl'. Comparison to untreated control.")  name(`sublbl'B, replace) 
graph combine `sublbl'A `sublbl'B, cols(2) iscale(*.8) title("") xsize(11) ysize(8.5) scale(.8)
graph export Vaccines_rr_graphs\G_`sublbl'.pdf, replace

* Binary liberty scale
summ liberty_scale
gen H1_highlib=liberty_scale>`r(mean)' & liberty_scale~=.
label var H1_highlib "High liberty"

gen H2_republican=0 if pid7_with_leaners==1
replace H2_republican=1 if pid7_with_leaners==2
label var H2_republican "Republican"

gen H3_woman=gender==2
label var H3_woman "Female"

summ risktaking
gen H4_likerisk= risktaking>r(mean) & risktaking~=.
label var H4_likerisk "High risk taking"

summ vacconf_scale
gen H5_highconf=vacconf_scale>r(mean) & vacconf_scale~=.
label var H5_highconf "High Vaccine Confidence"

gen H6_white=race2==1 if race2~=.
label var H6_white "White"

gen H7_rural=urbancity3==3 if urbancity3~=.
label var H7_rural "Rural"

forvalues ctr = 1(1)7 {
	foreach var of varlist treat_info treat_comm treat_commembarass treat_notbravery treat_science treat_freedom  {
		gen ZH`ctr'_`var' = H`ctr'_ * `var'
		gen ZHnot`ctr'_`var' = (1-H`ctr'_) * `var'
		local templabel : var label `var'
		local templabel = subinstr("`templabel'"," treatment","",.)
		di "`templabel'"
		unab temp: H`ctr'_
		di "`temp'"
		*local templabel : var label (variablename)
		local hetlabel : var label `temp'
		di "`hetlabel'"
		label var ZH`ctr'_`var' "`hetlabel' X `templabel'"
		label var  ZHnot`ctr'_`var' "NOT `hetlabel' X `templabel'"
		}
	order H`ctr'_* ZHnot`ctr'_* 	
	}


* Liberty endorsement
local spec = "het_lib"
local specdesc = "By Liberty Endorsement."

foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale  {
	*Note when segmenting by liberty drop PID i.pid7_nomiss
	regress `var' H1_highlib ZH1_* ZHnot1_*  i.age female income income_miss i.educ race_black race_hispanic race_other workathome workoutsidechoice workoutsidehaveto prior_flushot vacconf_scale anyhealthrisk, robust
	est store `var'

	qui summ `var' if e(sample) & message_split==1
	if "`var'" == "vaccinelikely_3month" {
	//	outreg2 using Vaccines_rr_tables\TableX_`spec'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)') replace
	}
	else {
	//	outreg2 using Vaccines_rr_tables\TableX_`spec'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)') append
	}		

}	

coefplot  vaccinelikely_3month vaccinelikely_year vaccinelikely_combined, keep(*ZH*1*) omitted levels(90) baselevels  xline(0)  title("A: Intention to Vaccinate", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Vaccine 3 Mos." 4 "Vaccine Year" 6 "Vaccine Combo") size(vsmall) on)  name(`sublbl'A, replace) xsize(11.5) ysize(8.5)
coefplot  vaccine_advisefriend judging_nonvacscale, keep(*ZH*1*) omitted levels(90) baselevels  xline(0)  title("B: Other-Regarding Outcomes", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Advise friend" 4 "Judging Non-Vaccinator") size(vsmall) on)  name(`sublbl'B, replace) xsize(11.5) ysize(8.5)
graph combine `sublbl'A `sublbl'B, cols(2) iscale(*.8) title("") xsize(11) ysize(8.5) scale(.8)
graph export Vaccines_rr_graphs\Het_`spec'.pdf, replace

* Partisanship
local spec = "het_pid"
local specdesc = "By PID."

foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale  {
	*Note when segmenting by pid drop PID i.pid7_nomiss
	regress `var' H2_republican ZH2_* ZHnot2_*  i.age female income income_miss i.educ race_black race_hispanic race_other workathome workoutsidechoice workoutsidehaveto prior_flushot vacconf_scale anyhealthrisk, robust
	est store `var'

	qui summ `var' if e(sample) & message_split==1
	if "`var'" == "vaccinelikely_3month" {
	//	outreg2 using Vaccines_rr_tables\TableX_`spec'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)') replace
	}
	else {
	//	outreg2 using Vaccines_rr_tables\TableX_`spec'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)') append
	}		

}	

coefplot  vaccinelikely_3month vaccinelikely_year vaccinelikely_combined, keep(*ZH*2*) omitted levels(95) baselevels  xline(0)  title("A: Intention to Vaccinate", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Vaccine 3 Mos." 4 "Vaccine Year" 6 "Vaccine Combo") size(vsmall) on)  name(`sublbl'A, replace) xsize(11.5) ysize(8.5)
coefplot  vaccine_advisefriend judging_nonvacscale, keep(*ZH*2*) omitted levels(95) baselevels  xline(0)  title("B: Other-Regarding Outcomes", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Advise friend" 4 "Judging Non-Vaccinator") size(vsmall) on) name(`sublbl'B, replace) xsize(11.5) ysize(8.5)
graph combine `sublbl'A `sublbl'B, cols(2) iscale(*.8) title("") xsize(11) ysize(8.5) scale(.8)
graph export Vaccines_rr_graphs\Het_`spec'.pdf, replace

* Gender
local spec = "het_gender"
local specdesc = "By Gender."

foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale  {

	regress `var' H3_woman ZH3_* ZHnot3_*  i.age female income income_miss i.educ i.pid7_nomiss race_black race_hispanic race_other workathome workoutsidechoice workoutsidehaveto prior_flushot vacconf_scale anyhealthrisk, robust
	est store `var'

	qui summ `var' if e(sample) & message_split==1
	if "`var'" == "vaccinelikely_3month" {
	//	outreg2 using Vaccines_rr_tables\TableX_`spec'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)') replace
	}
	else {
	//	outreg2 using Vaccines_rr_tables\TableX_`spec'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)') append
	}		

}	

coefplot  vaccinelikely_3month vaccinelikely_year vaccinelikely_combined, keep(*ZH*3*) omitted levels(95) baselevels  xline(0)  title("A: Intention to Vaccinate", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Vaccine 3 Mos." 4 "Vaccine Year" 6 "Vaccine Combo") size(vsmall) on)  name(`sublbl'A, replace) xsize(11.5) ysize(8.5)
coefplot  vaccine_advisefriend judging_nonvacscale, keep(*ZH*3*) omitted levels(95) baselevels  xline(0)  title("B: Other-Regarding Outcomes", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Advise friend" 4 "Judging Non-Vaccinator") size(vsmall) on)  name(`sublbl'B, replace) xsize(11.5) ysize(8.5)
graph combine `sublbl'A `sublbl'B, cols(2) iscale(*.8) title("") xsize(11) ysize(8.5) scale(.8)
graph export Vaccines_rr_graphs\Het_`spec'.pdf, replace


* Risk Taking
local spec = "het_risk"
local specdesc = "By Risk Taking."

foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale  {

	regress `var' H4_likerisk ZH4_* ZHnot4_*  i.age female income income_miss i.educ i.pid7_nomiss race_black race_hispanic race_other workathome workoutsidechoice workoutsidehaveto prior_flushot vacconf_scale anyhealthrisk, robust
	est store `var'

	qui summ `var' if e(sample) & message_split==1
	if "`var'" == "vaccinelikely_3month" {
		outreg2 using Vaccines_rr_tables\TableX_`spec'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)') replace
	}
	else {
		outreg2 using Vaccines_rr_tables\TableX_`spec'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)') append
	}	

}	

coefplot  vaccinelikely_3month vaccinelikely_year vaccinelikely_combined, keep(*ZH*4*) omitted levels(90) baselevels  xline(0)  title("A: Intention to Vaccinate", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Vaccine 3 Mos." 4 "Vaccine Year" 6 "Vaccine Combo") size(vsmall) on)  name(`sublbl'A, replace) xsize(11.5) ysize(8.5)
coefplot  vaccine_advisefriend judging_nonvacscale, keep(*ZH*4*) omitted levels(90) baselevels  xline(0)  title("B: Other-Regarding Outcomes", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Advise friend" 4 "Judging Non-Vaccinator") size(vsmall) on)  name(`sublbl'B, replace) xsize(11.5) ysize(8.5)
graph combine `sublbl'A `sublbl'B, cols(2) iscale(*.8) title("") xsize(11) ysize(8.5) scale(.8)
graph export Vaccines_rr_graphs\Het_`spec'.pdf, replace

* Vaccine Confidence
local spec = "het_vacconf"
local specdesc = "By Vaccine Confidence."

foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale  {

	regress `var' H5_highconf ZH5_* ZHnot5_*  i.age female income income_miss i.educ i.pid7_nomiss race_black race_hispanic race_other workathome workoutsidechoice workoutsidehaveto prior_flushot vacconf_scale anyhealthrisk, robust
	est store `var'

	qui summ `var' if e(sample) & message_split==1
	if "`var'" == "vaccinelikely_3month" {
		outreg2 using Vaccines_rr_tables\TableX_`spec'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)') replace
	}
	else {
		outreg2 using Vaccines_rr_tables\TableX_`spec'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)') append
	}

}	

coefplot  vaccinelikely_3month vaccinelikely_year vaccinelikely_combined, keep(*ZH*5*) omitted levels(95) baselevels  xline(0)  title("A: Intention to Vaccinate", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Vaccine 3 Mos." 4 "Vaccine Year" 6 "Vaccine Combo") size(vsmall) on)  name(`sublbl'A, replace) xsize(11.5) ysize(8.5)
coefplot  vaccine_advisefriend judging_nonvacscale, keep(*ZH*5*) omitted levels(95) baselevels  xline(0)  title("B: Other-Regarding Outcomes", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Advise friend" 4 "Judging Non-Vaccinator") size(vsmall) on)  name(`sublbl'B, replace) xsize(11.5) ysize(8.5)
graph combine `sublbl'A `sublbl'B, cols(2) iscale(*.8) title("") xsize(11) ysize(8.5) scale(.8)
graph export Vaccines_rr_graphs\Het_`spec'.pdf, replace


* RAce
local spec = "het_race"
local specdesc = "By Race."

foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale  {

	regress `var' H6_white ZH6_* ZHnot6_*  i.age female income income_miss i.educ i.pid7_nomiss race_black race_hispanic race_other workathome workoutsidechoice workoutsidehaveto prior_flushot vacconf_scale anyhealthrisk, robust
	est store `var'

	qui summ `var' if e(sample) & message_split==1
	if "`var'" == "vaccinelikely_3month" {
	//	outreg2 using Vaccines_rr_tables\TableX_`spec'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)') replace
	}
	else {
	//	outreg2 using Vaccines_rr_tables\TableX_`spec'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)') append
	}	

}	

coefplot  vaccinelikely_3month vaccinelikely_year vaccinelikely_combined, keep(*ZH*6*) omitted levels(95) baselevels  xline(0)  title("A: Intention to Vaccinate", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Vaccine 3 Mos." 4 "Vaccine Year" 6 "Vaccine Combo") size(vsmall) on)  name(`sublbl'A, replace) xsize(11.5) ysize(8.5)
coefplot  vaccine_advisefriend judging_nonvacscale, keep(*ZH*6*) omitted levels(95) baselevels  xline(0)  title("B: Other-Regarding Outcomes", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Advise friend" 4 "Judging Non-Vaccinator") size(vsmall) on)  name(`sublbl'B, replace) xsize(11.5) ysize(8.5)
graph combine `sublbl'A `sublbl'B, cols(2) iscale(*.8) title("") xsize(11) ysize(8.5) scale(.8)
graph export Vaccines_rr_graphs\Het_`spec'.pdf, replace

* Rural
local spec = "het_rural"
local specdesc = "By Rural."

foreach var of varlist vaccinelikely_3month vaccinelikely_year vaccinelikely_combined vaccine_advisefriend judging_nonvacscale  {

	regress `var' H7_rural ZH7_* ZHnot7_*  i.age female income income_miss i.educ i.pid7_nomiss race_black race_hispanic race_other workathome workoutsidechoice workoutsidehaveto prior_flushot vacconf_scale anyhealthrisk, robust
	est store `var'

	qui summ `var' if e(sample) & message_split==1
	if "`var'" == "vaccinelikely_3month" {
	//	outreg2 using Vaccines_rr_tables\TableX_`spec'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)') replace
	}
	else {
	//	outreg2 using Vaccines_rr_tables\TableX_`spec'.out, se bracket rdec(3) adec(3) addstat("Control Group Mean of DV",`r(mean)') append
	}	

}	

coefplot  vaccinelikely_3month vaccinelikely_year vaccinelikely_combined, keep(*ZH*7*) omitted levels(95) baselevels  xline(0)  title("A: Intention to Vaccinate", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Vaccine 3 Mos." 4 "Vaccine Year" 6 "Vaccine Combo") size(vsmall) on)  name(`sublbl'A, replace) xsize(11.5) ysize(8.5)
coefplot  vaccine_advisefriend judging_nonvacscale, keep(*ZH*7*) omitted levels(95) baselevels  xline(0)  title("B: Other-Regarding Outcomes", size(small)) xlabel(, labels labsize(vsmall)) ylabel(, labels labsize(small)) legend(order(2 "Advise friend" 4 "Judging Non-Vaccinator") size(vsmall) on)  name(`sublbl'B, replace) xsize(11.5) ysize(8.5)
graph combine `sublbl'A `sublbl'B, cols(2) iscale(*.8) title("") xsize(11) ysize(8.5) scale(.8)
graph export Vaccines_rr_graphs\Het_`spec'.pdf, replace
